<?php
    
    namespace common\models;
    
    use artbox\core\behaviors\BitMaskBehavior;
    use artbox\core\behaviors\LanguageBehavior;
    use artbox\core\models\PageLang;
    use yii\db\ActiveQuery;
    use yii\db\ActiveRecord;
    use yii\web\Request;
    use Yii;
    
    /**
     * This is the model class for table "page".
     *
     * @property integer    $id
     * @property bool       $in_menu
     * @property integer    $sort
     *      * From language behavior *
     * @property PageLang   $lang
     * @property PageLang[] $langs
     * @property PageLang   $objectLang
     * @property string     $ownerKey
     * @property string     $langKey
     * @property PageLang[] $modelLangs
     * @property bool       $transactionStatus
     * @method string       getOwnerKey()
     * @method void         setOwnerKey( string $value )
     * @method string       getLangKey()
     * @method void         setLangKey( string $value )
     * @method ActiveQuery  getLangs()
     * @method ActiveQuery  getLang( integer $language_id )
     * @method PageLang[]   generateLangs()
     * @method void         loadLangs( Request $request )
     * @method bool         linkLangs()
     * @method bool         saveLangs()
     * @method bool         getTransactionStatus()
     * @method bool         loadWithLangs( Request $request )
     * @method bool         saveWithLangs()
     *      * End language behavior *
     * @see LanguageBehavior
     * @method void         loadMask( Request $request )
     */
    class Page extends ActiveRecord
    {
        /**
         * @inheritdoc
         */
        public static function tableName()
        {
            return 'page';
        }
        
        /**
         * @inheritdoc
         */
        public function behaviors()
        {
            return [
                'language' => [
                    'class'      => LanguageBehavior::className(),
                    'objectLang' => PageLang::className(),
                ],
                [
                    'class'  => BitMaskBehavior::className(),
                    'fields' => [
                        'Service'  => 0,
                        'Solution' => 1,
                        'About'    => 2,
                    ],
                ],
            ];
        }
        
        /**
         * @inheritdoc
         */
        public function rules()
        {
            return [
                [
                    [
                        'in_menu',
                    ],
                    'boolean',
                ],
                [
                    [ 'mask' ],
                    'integer',
                ],
                [
                    [
                        'sort',
                    ],
                    'integer',
                    'min' => 0,
                ],
            ];
        }
        
        /**
         * @inheritdoc
         */
        public function attributeLabels()
        {
            return [
                'id'      => Yii::t('core', 'Id'),
                'in_menu' => Yii::t('core', 'Use in menu'),
                'sort'    => Yii::t('core', 'Sort'),
            ];
        }
    }
