<?php
    /**
     * @var View         $this
     * @var string       $content
     * @var SeoComponent $seo
     * @var User         $user
     */
    use artbox\core\components\SeoComponent;
    use artbox\core\helpers\ImageHelper;
    use artbox\core\models\Feedback;
    use common\models\Page;
    use artbox\core\models\User;
    use common\models\Settings;
    use frontend\assets\AppAsset;
    use noam148\imagemanager\models\ImageManager;
    use yii\bootstrap\ActiveForm;
    use yii\bootstrap\Nav;
    use yii\bootstrap\Html;
    use yii\helpers\Json;
    use yii\helpers\Url;
    use yii\web\View;
    use yii\widgets\Breadcrumbs;
    
    AppAsset::register($this);
    $user = \Yii::$app->user->identity;
    $seo = Yii::$app->get('seo');
    $feedback = new Feedback();
    $settings = Settings::getInstance();
    $controller = Yii::$app->controller;
    $default_controller = Yii::$app->defaultRoute;
    $isHome = ( ( $controller->id === $default_controller ) && ( $controller->action->id === $controller->defaultAction ) ) ? true : false;
    /**
     * @var Page[] $services
     * @var Page[] $solutions
     * @var Page $about
     */
    $services = Page::find()
                 ->where([ 'in_menu' => true ])
                 ->andWhere([
                   '!=',
                   '(mask & 1)',
                   0
                            ])
                 ->with('lang.alias')
                 ->orderBy('sort')
                 ->all();
    $solutions = Page::find()
                     ->where([ 'in_menu' => true ])
                     ->andWhere([
                                    '!=',
                                    '(mask & 2)',
                                    0
                                ])
                     ->with('lang.alias')
                     ->orderBy('sort')
                     ->all();
    $about = Page::find()
                 ->where([ 'in_menu' => true ])
                 ->andWhere([
                                '!=',
                                '(mask & 4)',
                                0
                            ])
                 ->with('lang.alias')
                 ->one();
    $logo = null;
    if ($settings->logo) {
        $logo_img = ImageManager::findOne($settings->logo);
        if ($logo_img) {
            $logo = $logo_img->getImagePathPrivate() ?? $logo;
        }
    }
    
    $this->registerMetaTag(
        [
            'name'    => 'description',
            'content' => $seo->desc,
        ]
    )
?>

<?php $this->beginPage() ?>
  
  <!DOCTYPE html>
  <html lang="<?= \Yii::$app->language ?>">
    <head>
      <meta charset="<?= \Yii::$app->charset ?>">
      <meta name="viewport" content="width=device-width, initial-scale=1">
        <?= Html::csrfMetaTags() ?>
      <title><?= Html::encode($seo->title) ?></title>
        <?php $this->head() ?>
    </head>
    <body>
        <?php $this->beginBody() ?>
      <!-- Google Analytics -->
      <script>
          (function(i, s, o, g, r, a, m) {
              i[ 'GoogleAnalyticsObject' ] = r;
              i[ r ] = i[ r ] || function() {
                      (i[ r ].q = i[ r ].q || []).push(arguments)
                  }, i[ r ].l = 1 * new Date();
              a = s.createElement(o), m = s.getElementsByTagName(o)[ 0 ];
              a.async = 1;
              a.src = g;
              m.parentNode.insertBefore(a, m)
          })(window, document, 'script', 'https://www.google-analytics.com/analytics.js', 'ga');

          ga('create', <?=$settings->ga_code?>, 'auto');
          ga('send', 'pageview');
  
      </script>
      <div id="all">
        <header>
          <!-- *** TOP ***
_________________________________________________________ -->
          <div id="top">
            <div class="container">
              <div class="row">
                <div class="col-xs-5 contact">
                  <p class="hidden-sm hidden-xs">
                      <?php
                          if (!empty($settings->phone)) {
                              echo \Yii::t('app', 'Contact us on ');
                              echo Html::a($settings->phone, "tel: {$settings->phone}");
                              if (!empty($settings->email)) {
                                  echo \Yii::t('app', ' or ');
                                  echo Html::a($settings->email, "mailto:$settings->email");
                              }
                          }
                      ?>
                  </p>
                  <p class="hidden-md hidden-lg">
                    <a href="#" data-animate-hover="pulse"><i class="fa fa-phone"></i></a>
                    <a href="#" data-animate-hover="pulse"><i class="fa fa-envelope"></i></a>
                  </p>
                </div>
                <div class="col-xs-7">
                  <div class="social">
                      <?php
                          if (!empty($settings->facebook)) {
                              echo Html::a(
                                  Html::icon(
                                      'facebook',
                                      [
                                          'prefix' => 'fa fa-',
                                      ]
                                  ),
                                  $settings->facebook,
                                  [
                                      'class' => 'external facebook',
                                      'data'  => [
                                          'animate-hover' => 'pulse',
                                      ],
                                  ]
                              );
                          }
                      ?>
                      <?php
                          if (!empty($settings->vk)) {
                              echo Html::a(
                                  Html::icon(
                                      'vk',
                                      [
                                          'prefix' => 'fa fa-',
                                      ]
                                  ),
                                  $settings->vk,
                                  [
                                      'class' => 'external vk',
                                      'data'  => [
                                          'animate-hover' => 'pulse',
                                      ],
                                  ]
                              );
                          }
                      ?>
                      <?php
                          if (!empty($settings->google)) {
                              echo Html::a(
                                  Html::icon(
                                      'google-plus',
                                      [
                                          'prefix' => 'fa fa-',
                                      ]
                                  ),
                                  $settings->google,
                                  [
                                      'class' => 'external gplus',
                                      'data'  => [
                                          'animate-hover' => 'pulse',
                                      ],
                                  ]
                              );
                          }
                      ?>
                      <?php
                          if (!empty($settings->twitter)) {
                              echo Html::a(
                                  Html::icon(
                                      'twitter',
                                      [
                                          'prefix' => 'fa fa-',
                                      ]
                                  ),
                                  $settings->twitter,
                                  [
                                      'class' => 'external twitter',
                                      'data'  => [
                                          'animate-hover' => 'pulse',
                                      ],
                                  ]
                              );
                          }
                      ?>
                      <?php
                          if (!empty($settings->ok)) {
                              echo Html::a(
                                  Html::icon(
                                      'odnoklassniki',
                                      [
                                          'prefix' => 'fa fa-',
                                      ]
                                  ),
                                  $settings->ok,
                                  [
                                      'class' => 'external odnoklassniki',
                                      'data'  => [
                                          'animate-hover' => 'pulse',
                                      ],
                                  ]
                              );
                          }
                      ?>
                      <?php
                          if (!empty($settings->email)) {
                              echo Html::a(
                                  Html::icon(
                                      'envelope',
                                      [
                                          'prefix' => 'fa fa-',
                                      ]
                                  ),
                                  "mailto:$settings->email",
                                  [
                                      'class' => 'email',
                                      'data'  => [
                                          'animate-hover' => 'pulse',
                                      ],
                                  ]
                              );
                          }
                      ?>
                  </div>
                </div>
              </div>
            </div>
          </div>
          <!-- *** TOP END *** -->
          
          <!-- *** NAVBAR ***
  _________________________________________________________ -->
          <div class="navbar-affixed-top" data-spy="affix" data-offset-top="200">
            
            <div class="navbar navbar-default yamm" role="navigation" id="navbar">
              
              <div class="container">
                <div class="navbar-header">
                  
                  <a class="navbar-brand home" href="<?php echo Url::home(); ?>">
                      <?php
                          echo ImageHelper::set($logo)
                                          ->setHeight(42)
                                          ->renderImage(
                                              [
                                                  'alt' => $settings->name,
                                              ]
                                          )
                      ?>
                  </a>
                  <div class="navbar-buttons">
                    <button type="button" class="navbar-toggle btn-template-main" data-toggle="collapse" data-target="#navigation">
                      <span class="sr-only">Toggle navigation</span>
                      <i class="fa fa-align-justify"></i>
                    </button>
                  </div>
                </div>
                
                <div class="navbar-collapse collapse" id="navigation">
                    <?php
                        $servicesLinks = [];
                        foreach ($services as $page) {
                            $route = [
                                'page/view',
                                'id' => $page->id,
                            ];
                            if (!empty($page->lang->alias) && !empty($page->lang->alias->route)) {
                                $route = Json::decode($page->lang->alias->route);
                            }
                            $servicesLinks[] = [
                                'label' => $page->lang->title,
                                'url'   => $route,
                            ];
                        }
                        $solutionsLinks = [];
                        foreach ($solutions as $page) {
                            $route = [
                                'page/view',
                                'id' => $page->id,
                            ];
                            if (!empty($page->lang->alias) && !empty($page->lang->alias->route)) {
                                $route = Json::decode($page->lang->alias->route);
                            }
                            $solutionsLinks[] = [
                                'label' => $page->lang->title,
                                'url'   => $route,
                            ];
                        }
                        echo Nav::widget(
                            [
                                'items'   => [
                                    [
                                        'label' => \Yii::t('app', 'Home'),
                                        'url'   => [ 'site/index' ],
                                    ],
                                    [
                                        'label'   => \Yii::t('app', 'Services'),
                                        'items'   => $servicesLinks,
                                        'visible' => count($servicesLinks),
                                    ],
                                    [
                                        'label'   => \Yii::t('app', 'Solutions'),
                                        'items'   => $solutionsLinks,
                                        'visible' => count($solutionsLinks),
                                    ],
                                    [
                                        'label'   => \Yii::t('app', 'About'),
                                        'url' => empty($about) ? '#' : ['page/view', 'id' => $about->id],
                                        'visible' => !empty($about),
                                    ],
                                    [
                                        'label' => \Yii::t('app', 'Contacts'),
                                        'url'   => [ 'site/contact' ],
                                    ],
                                ],
                                'options' => [
                                    'class' => 'nav navbar-nav navbar-right',
                                ],
                            ]
                        );
                    ?>
                </div>
                
                
                <div class="collapse clearfix" id="search">
                  
                  <form class="navbar-form" role="search">
                    <div class="input-group">
                      <input type="text" class="form-control" placeholder="Поиск">
                      <span class="input-group-btn">

                    <button type="submit" class="btn btn-template-main"><i class="fa fa-search"></i></button>

                </span>
                    </div>
                  </form>
                
                </div>
                <!--/.nav-collapse -->
              
              </div>
            
            
            </div>
            <!-- /#navbar -->
          
          </div>
          
          <!-- *** NAVBAR END *** -->
        
        </header>
        
        <!-- *** FeedBack MODAL ***
_________________________________________________________ -->
        
        <div class="modal fade" id="success-modal" tabindex="-1" role="dialog" aria-labelledby="Success" aria-hidden="true">
          <div class="modal-dialog">
            
            <div class="modal-content">
              <div class="modal-header">
                <button type="button" class="close" data-dismiss="modal" aria-hidden="true">&times</button>
                <h3 class="modal-title" id="Success">Успех</h3>
              </div>
              <div class="modal-body">
                
                <p>Спасибо за ваше сообщение.</p>
                <p class="text-center">
                  <button type="button" class="btn btn-template-primary" data-dismiss="modal">Закрыть</button>
                </p>
              </div>
            </div>
          </div>
        </div>
        
        <!-- *** FeedBack MODAL END *** -->
        
        <!-- *** Breadcrumbs *** -->
          <?php
              if (!$isHome) {
                  ?>
                <div id="heading-breadcrumbs">
                  <div class="container">
                    <div class="row">
                      <div class="col-md-7">
                        <h1><?= $seo->h1 ?></h1>
                      </div>
                      <div class="col-md-5">
                          <?= Breadcrumbs::widget(
                              [
                                  'links' => isset($this->params[ 'breadcrumbs' ]) ? $this->params[ 'breadcrumbs' ] : [],
                              ]
                          ) ?>
                      
                      </div>
                    </div>
                  </div>
                </div>
                  <?php
              }
          ?>
        <!-- *** Breadcrumbs END *** -->
          
          <?= $content ?>
        
        <!-- *** FOOTER ***
_________________________________________________________ -->
        
        <!-- /#footer -->
        <footer id="footer">
          <div class="container">
            <div class="col-md-3 col-sm-6">
              <h4>О нас</h4>
              <p><?php
                  if (!empty($settings->about)) echo $settings->about;
                  ?></p>
              <hr class="hidden-md hidden-lg hidden-sm">
            </div>
            <div class="hidden-xs hidden-sm col-md-6"></div>
            <div class="col-md-3 col-sm-6">
        
              <h4>Контакты</h4>
        
              <p><?php
                  if (!empty($settings->street)) echo $settings->street;
                  if (!empty($settings->house)) echo ', ' . $settings->house;
                  ?>
                <br /><?php
                  if (!empty($settings->index)) echo $settings->index . ',';
                  ?>
                <br /><?php if (!empty($settings->city)) echo $settings->city . ','; ?> <strong><?php
                      if (!empty($settings->country)) echo $settings->country;
                      ?></strong>
              </p>
        
              <!--<a href="contacts.html" class="btn btn-small btn-template-main">перейти в контакты</a>-->
              <a href="<?= Url::to(['site/contact'])?>" class="btn btn-footer-custom">перейти в контакты</a>
        
              <hr class="hidden-md hidden-lg hidden-sm">
      
            </div>
            <!-- /.col-md-3 -->
      
      
      
      
            <!-- /.col-md-3 -->
          </div>
          <!-- /.container -->
        </footer>
        <!-- *** FOOTER END *** -->
        <div id="copyright">
          <div class="container">
            <div class="col-md-12">
              <p class="pull-left">&copy; <?php
                  if (!empty($settings->name)) echo $settings->name;
                  ?>, <?php echo date('Y')?>.</p>
              <p class="pull-right">
                <a class="artweb-link" target="_blank" href="http://artweb.ua/">Создание сайтов</a>
              </p>
            </div>
          </div>
        </div>
      </div>
      <!-- /#all -->
        <?php $this->endBody() ?>
    </body>
  </html>
<?php $this->endPage() ?>