<?php
    
    /**
     * @var View     $this
     * @var Feedback $contact
     */
    
    use artbox\core\models\Feedback;
    use common\models\Settings;
    use frontend\assets\MapAsset;
    use yii\helpers\Html;
    use yii\bootstrap\ActiveForm;
    use yii\web\View;
    
    MapAsset::register($this);
    $settings = Settings::getInstance();
    
    $this->title = \Yii::t('app', 'Contact');
    $this->params[ 'breadcrumbs' ][] = $this->title;
    
    $js = <<< JS
window.lat = {$settings->lat};
window.lon = {$settings->lon};
JS;
    
    $this->registerJs($js, View::POS_END);
?>


<div id="content">
  <div class="container" id="contact">
    
    <section>
      
      <div class="row">
        <div class="col-md-12">
          <section>
            <div class="heading">
              <h2>Мы работаем для вас</h2>
            </div>
            
            <p class="lead">Мы всегда готовы помочь вам выбрать оптимальный вариант оборудования, который покроет ваши потребности и не ударит по карману. Также будем рады ответить на все возникшие вопросы.</p>
            <p>Пожалуйста, оставьте ваши данные и мы свяжемся с вами в ближайшее время.</p>
          </section>
        </div>
      </div>
    
    </section>
    
    <section>
      
      <div class="row">
        <div class="col-md-4">
          <div class="box-simple">
            <div class="icon">
              <i class="fa fa-map-marker"></i>
            </div>
            <h3>Адрес</h3>
            <p><?php if (!empty($settings->street)) {
                    echo $settings->street . ',';
                } ?> <?php
                    if (!empty($settings->house)) {
                        echo $settings->house;
                    }
                ?>
              <br/><?php if (!empty($settings->index)) {
                    echo $settings->index . ',';
                } ?>
              <br/><?php
                    if (!empty($settings->city)) {
                        echo $settings->city . ',';
                    }
                ?> <strong><?php if (!empty($settings->country)) {
                        echo $settings->country;
                    } ?></strong>
            </p>
          </div>
          <!-- /.box-simple -->
        </div>
        
        
        <div class="col-md-4">
          
          <div class="box-simple">
            <div class="icon">
              <i class="fa fa-phone"></i>
            </div>
            <h3>Телефоны</h3>
            <p><strong><?php if (!empty($settings->phone)) {
                        echo $settings->phone;
                    } ?></strong>
            <p><strong><?php if (!empty($settings->phone2)) {
                        echo $settings->phone2;
                    } ?></strong>
            </p>
          </div>
          <!-- /.box-simple -->
        
        </div>
        
        <div class="col-md-4">
          
          <div class="box-simple">
            <div class="icon">
              <i class="fa fa-envelope"></i>
            </div>
            <h3>Электронный адрес</h3>
            <ul class="list-style-none" style="padding-left: 0">
                <?php if (!empty($settings->email)) { ?>
                  <li><strong><a href="mailto:<?= $settings->email; ?>"><?= $settings->email; ?></a></strong>
                  </li>
                <?php } ?>
            </ul>
          </div>
          <!-- /.box-simple -->
        </div>
      </div>
    
    </section>
    
    <section>
      
      <div class="row">
        
        <div class="col-md-12  text-center">
          <div class="heading">
            <h2>Возникли вопросы или предложения?</h2>
          </div>
        </div>
        
        <div class="col-md-8 col-md-offset-2">
            <?php $form = ActiveForm::begin(
                [
                    'id'     => 'contact-form',
                    'method' => 'POST',
                    'action' => '/site/feedback',
                ]
            ); ?>
          <div class="row">
            <div class="col-sm-12 col-xs-12">
                <?= $form->field($contact, 'name')
                         ->textInput(); ?>
            </div>
            
            <div class="col-sm-12 col-xs-12">
                <?= $form->field($contact, 'email')
                         ->textInput(); ?>
            </div>
            
            <div class="col-sm-12 col-xs-12">
                <?= $form->field($contact, 'phone')
                         ->textInput(); ?>
            </div>
            
            <div class="col-sm-12 col-xs-12">
                <?= $form->field($contact, 'message')
                         ->textarea(
                             [
                                 'rows' => 3,
                             ]
                         ) ?>
            </div>
            
            <div class="col-sm-12 col-xs-12 text-center">
                <?php
                    echo Html::submitButton(
                        Html::tag('i', '', [ 'class' => 'fa fa-envelope-o' ]) . ' Отправить',
                        [
                            'class' => 'btn btn-template-main',
                        ]
                    )
                ?>
            </div>
          </div>
          <!-- /.row -->
            <?php $form::end(); ?>
        
        
        </div>
      </div>
      <!-- /.row -->
    
    </section>
  
  
  </div>
  <!-- /#contact.container -->
</div>

<div id="map">

</div>